COMPMID-576: Port Phase to new validation

Change-Id: Ice08031c997cf8162a4358deb059db857ede2382
Reviewed-on: http://mpd-gerrit.cambridge.arm.com/93585
Tested-by: Kaizen <jeremy.johnson+kaizengerrit@arm.com>
Reviewed-by: Anthony Barbier <anthony.barbier@arm.com>
diff --git a/arm_compute/runtime/NEON/functions/NEPhase.h b/arm_compute/runtime/NEON/functions/NEPhase.h
index 985ba84..cd62cf9 100644
--- a/arm_compute/runtime/NEON/functions/NEPhase.h
+++ b/arm_compute/runtime/NEON/functions/NEPhase.h
@@ -36,11 +36,12 @@
 public:
     /** Initialise the kernel's inputs, output.
      *
      * @param[in]  input1 First tensor input. Data type supported: S16.
      * @param[in]  input2 Second tensor input. Data type supported: S16.
      * @param[out] output Output tensor. Data type supported: U8.
      */
-    void configure(const ITensor *input1, const ITensor *input2, ITensor *output);
+    void configure(const ITensor *input1, const ITensor *input2, ITensor *output, PhaseType phase_type = PhaseType::SIGNED);
 };
 }
 #endif /*__ARM_COMPUTE_NEPHASE_H__ */
@@ -36,11 +36,12 @@
     /** Initialise the kernel's inputs, output.
      *
-     * @param[in]  input1 First tensor input. Data type supported: S16.
-     * @param[in]  input2 Second tensor input. Data type supported: S16.
-     * @param[out] output Output tensor. Data type supported: U8.
+     * @param[in]  input1     First tensor input. Data type supported: S16.
+     * @param[in]  input2     Second tensor input. Data type supported: S16.
+     * @param[out] output     Output tensor. Data type supported: U8.
+     * @param[in]  phase_type (Optional) Phase calculation type. Default: SIGNED.
      */